@@ -1,7 +1,7 @@
-# from .<ファイル> import *
+from .only_common import *
 
 __copyright__    = 'Copyright (C) 2021 Takao Morita'
-__version__      = '1.0.0'
+__version__      = '2.0.0'
 __license__      = 'MIT'
 __author__       = 'Takao Morita'
 __author_email__ = 'tmolita077@gmail.com'
